==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebSliderBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderBaseDescription } from "./WebSliderBaseDescription";
/**
 * @hidden
 */
export let WebSliderBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderBaseDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderBaseDescriptionMetadata.a == null) {
                WebSliderBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderBaseDescriptionMetadata.c(WebSliderBaseDescriptionMetadata.a);
            }
            if (a.k(WebSliderBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSliderBaseDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SliderBase");
            a.item("__tagNameWC", "String:igc-slider-base");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Min", "Number:double");
            a.item("Max", "Number:double");
            a.item("LowerBound", "Number:double");
            a.item("UpperBound", "Number:double");
            a.item("Disabled", "Boolean");
            a.item("DiscreteTrack", "Boolean");
            a.item("HideTooltip", "Boolean");
            a.item("Step", "Number:double");
            a.item("PrimaryTicks", "Number:double");
            a.item("SecondaryTicks", "Number:double");
            a.item("TickOrientation", "ExportedType:string:SliderBaseTickOrientation");
            a.item("TickOrientation@stringUnion", "WebComponents;React");
            a.item("TickOrientation@names", "Start;End;Mirror");
            a.item("HidePrimaryLabels", "Boolean");
            a.item("HideSecondaryLabels", "Boolean");
            a.item("Locale", "String");
            a.item("ValueFormat", "String");
            a.item("TickLabelRotation", "ExportedType:string:TickLabelRotation");
            a.item("TickLabelRotation@names", "Zero;Ninety;NegativeNinety");
            a.item("ValueFormatOptions", "ExportedType");
        }
        static d(a) {
            WebSliderBaseDescriptionMetadata.b(a);
            a.ad("WebSliderBase", () => new WebSliderBaseDescription());
            a.ac("WebSliderBase", WebSliderBaseDescriptionMetadata.a);
        }
    }
    WebSliderBaseDescriptionMetadata.$t = markType(WebSliderBaseDescriptionMetadata, 'WebSliderBaseDescriptionMetadata');
    WebSliderBaseDescriptionMetadata.a = null;
    return WebSliderBaseDescriptionMetadata;
})();

==> igniteui-angular-core-19.0.1.tgz: package/esm2015/lib/WebSliderBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderBaseDescription } from "./WebSliderBaseDescription";
/**
 * @hidden
 */
export let WebSliderBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderBaseDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderBaseDescriptionMetadata.a == null) {
                WebSliderBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderBaseDescriptionMetadata.c(WebSliderBaseDescriptionMetadata.a);
            }
            if (a.k(WebSliderBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSliderBaseDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SliderBase");
            a.item("__tagNameWC", "String:igc-slider-base");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Min", "Number:double");
            a.item("Max", "Number:double");
            a.item("LowerBound", "Number:double");
            a.item("UpperBound", "Number:double");
            a.item("Disabled", "Boolean");
            a.item("DiscreteTrack", "Boolean");
            a.item("HideTooltip", "Boolean");
            a.item("Step", "Number:double");
            a.item("PrimaryTicks", "Number:double");
            a.item("SecondaryTicks", "Number:double");
            a.item("TickOrientation", "ExportedType:string:SliderBaseTickOrientation");
            a.item("TickOrientation@stringUnion", "WebComponents;React");
            a.item("TickOrientation@names", "End;Mirror;Start");
            a.item("HidePrimaryLabels", "Boolean");
            a.item("HideSecondaryLabels", "Boolean");
            a.item("Locale", "String");
            a.item("ValueFormat", "String");
            a.item("TickLabelRotation", "ExportedType:string:TickLabelRotation");
            a.item("TickLabelRotation@names", "Zero;Ninety;NegativeNinety");
            a.item("ValueFormatOptions", "ExportedType");
        }
        static d(a) {
            WebSliderBaseDescriptionMetadata.b(a);
            a.ae("WebSliderBase", () => new WebSliderBaseDescription());
            a.ad("WebSliderBase", WebSliderBaseDescriptionMetadata.a);
        }
    }
    WebSliderBaseDescriptionMetadata.$t = markType(WebSliderBaseDescriptionMetadata, 'WebSliderBaseDescriptionMetadata');
    WebSliderBaseDescriptionMetadata.a = null;
    return WebSliderBaseDescriptionMetadata;
})();
